@@ -1,7 +1,6 @@
 package yqlib
 
 import (
-	"regexp"
 	"strconv"
 	"strings"
 
@@ -13,10 +12,6 @@ var participleYqRules = []*participleYqRule{
 	{"HEAD_COMMENT", `head_?comment|headComment`, opTokenWithPrefs(getCommentOpType, assignCommentOpType, commentOpPreferences{HeadComment: true}), 0},
 	{"FOOT_COMMENT", `foot_?comment|footComment`, opTokenWithPrefs(getCommentOpType, assignCommentOpType, commentOpPreferences{FootComment: true}), 0},
 
-	{"SliceArray", `\.\[-?[0-9]+:-?[0-9]+\]`, sliceArrayTwoNumbers(), 0},
-	{"SliceArraySecond", `\.\[\:-?[0-9]+\]`, sliceArraySecondNumberOnly(), 0},
-	{"SliceArrayFirst", `\.\[-?[0-9]+\:\]`, sliceArrayFirstNumberOnly(), 0},
-
 	{"OpenBracket", `\(`, literalToken(openBracket, false), 0},
 	{"CloseBracket", `\)`, literalToken(closeBracket, true), 0},
 	{"OpenTraverseArrayCollect", `\.\[`, literalToken(traverseArrayCollect, false), 0},
@@ -55,6 +50,8 @@ var participleYqRules = []*participleYqRule{
 	simpleOp("sortKeys", sortKeysOpType),
 	simpleOp("sort_?keys", sortKeysOpType),
 
+	{"ArrayToMap", "array_?to_?map", expressionOpToken(`(.[] | select(. != null) ) as $i ireduce({}; .[$i | key] = $i)`), 0},
+
 	{"YamlEncodeWithIndent", `to_?yaml\([0-9]+\)`, encodeParseIndent(YamlOutputFormat), 0},
 	{"XMLEncodeWithIndent", `to_?xml\([0-9]+\)`, encodeParseIndent(XMLOutputFormat), 0},
 	{"JSONEncodeWithIndent", `to_?json\([0-9]+\)`, encodeParseIndent(JSONOutputFormat), 0},
@@ -291,6 +288,14 @@ func opTokenWithPrefs(opType *operationType, assignOpType *operationType, prefer
 	}
 }
 
+func expressionOpToken(expression string) yqAction {
+	return func(rawToken lexer.Token) (*token, error) {
+		prefs := expressionOpPreferences{expression: expression}
+		expressionOp := &Operation{OperationType: expressionOpType, Preferences: prefs}
+		return &token{TokenType: operationToken, Operation: expressionOp}, nil
+	}
+}
+
 func flattenWithDepth() yqAction {
 	return func(rawToken lexer.Token) (*token, error) {
 		value := rawToken.Value
@@ -305,84 +310,6 @@ func flattenWithDepth() yqAction {
 	}
 }
 
-func sliceArrayTwoNumbers() yqAction {
-	return func(rawToken lexer.Token) (*token, error) {
-		value := rawToken.Value
-		sliceArrayNumbers := regexp.MustCompile(`\.\[(-?[0-9]+)\:(-?[0-9]+)\]`)
-		matches := sliceArrayNumbers.FindStringSubmatch(value)
-		log.Debug("sliceArrayTwoNumbers value: %v", value)
-		log.Debug("Matches: %v", matches)
-
-		firstNumber, err := parseInt(matches[1])
-		if err != nil {
-			return nil, err
-		}
-		secondNumber, err := parseInt(matches[2])
-		if err != nil {
-			return nil, err
-		}
-
-		prefs := sliceArrayPreferences{
-			firstNumber:         firstNumber,
-			secondNumber:        secondNumber,
-			secondNumberDefined: true,
-		}
-		log.Debug("%v", prefs)
-
-		op := &Operation{OperationType: sliceArrayOpType, Value: sliceArrayOpType.Type, StringValue: value, Preferences: prefs}
-		return &token{TokenType: operationToken, Operation: op}, nil
-	}
-}
-
-func sliceArraySecondNumberOnly() yqAction {
-	return func(rawToken lexer.Token) (*token, error) {
-		value := rawToken.Value
-		sliceArrayNumbers := regexp.MustCompile(`\.\[\:(-?[0-9]+)\]`)
-		matches := sliceArrayNumbers.FindStringSubmatch(value)
-		log.Debug("sliceArraySecondNumberOnly value: %v", value)
-		log.Debug("Matches: %v", matches)
-
-		secondNumber, err := parseInt(matches[1])
-		if err != nil {
-			return nil, err
-		}
-
-		prefs := sliceArrayPreferences{
-			firstNumber:         0,
-			secondNumber:        secondNumber,
-			secondNumberDefined: true,
-		}
-		log.Debug("%v", prefs)
-
-		op := &Operation{OperationType: sliceArrayOpType, Value: sliceArrayOpType.Type, StringValue: value, Preferences: prefs}
-		return &token{TokenType: operationToken, Operation: op}, nil
-	}
-}
-
-func sliceArrayFirstNumberOnly() yqAction {
-	return func(rawToken lexer.Token) (*token, error) {
-		value := rawToken.Value
-		sliceArrayNumbers := regexp.MustCompile(`\.\[(-?[0-9]+)\:\]`)
-		matches := sliceArrayNumbers.FindStringSubmatch(value)
-		log.Debug("sliceArrayFirstNumberOnly value: %v", value)
-		log.Debug("Matches: %v", matches)
-
-		firstNumber, err := parseInt(matches[1])
-		if err != nil {
-			return nil, err
-		}
-
-		prefs := sliceArrayPreferences{
-			firstNumber:         firstNumber,
-			secondNumberDefined: false,
-		}
-		log.Debug("%v", prefs)
-
-		op := &Operation{OperationType: sliceArrayOpType, Value: sliceArrayOpType.Type, StringValue: value, Preferences: prefs}
-		return &token{TokenType: operationToken, Operation: op}, nil
-	}
-}
-
 func assignAllCommentsOp(updateAssign bool) yqAction {
 	return func(rawToken lexer.Token) (*token, error) {
 		log.Debug("assignAllCommentsOp %v", rawToken.Value)
