@@ -2,7 +2,24 @@ package yqlib
 
 func alternativeOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
 	log.Debugf("-- alternative")
-	return crossFunction(d, context.ReadOnlyClone(), expressionNode, alternativeFunc, true)
+	prefs := crossFunctionPreferences{
+		CalcWhenEmpty: true,
+		Calculation:   alternativeFunc,
+		LhsResultValue: func(lhs *CandidateNode) (*CandidateNode, error) {
+			if lhs == nil {
+				return nil, nil
+			}
+			truthy, err := isTruthy(lhs)
+			if err != nil {
+				return nil, err
+			}
+			if truthy {
+				return lhs, nil
+			}
+			return nil, nil
+		},
+	}
+	return crossFunctionWithPrefs(d, context, expressionNode, prefs)
 }
 
 func alternativeFunc(d *dataTreeNavigator, context Context, lhs *CandidateNode, rhs *CandidateNode) (*CandidateNode, error) {
