@@ -44,6 +44,13 @@ var traversePathOperatorScenarios = []expressionScenario{
 			"D0, P[0 0], (!!int)::1\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		expression: `.cat["12"] = "things"`,
+		expected: []string{
+			"D0, P[], ()::cat:\n    \"12\": things\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `blah: {}`,
